# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDirectConnectGatewayResult',
    'AwaitableGetDirectConnectGatewayResult',
    'get_direct_connect_gateway',
    'get_direct_connect_gateway_output',
]

@pulumi.output_type
class GetDirectConnectGatewayResult:
    """
    A collection of values returned by getDirectConnectGateway.
    """
    def __init__(__self__, account_id=None, associate_cens=None, bgp_asn=None, business_status=None, created_time=None, deleted_time=None, description=None, direct_connect_gateway_id=None, direct_connect_gateway_name=None, enable_ipv6=None, id=None, lock_reason=None, overdue_time=None, project_name=None, status=None, tags=None, updated_time=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if associate_cens and not isinstance(associate_cens, list):
            raise TypeError("Expected argument 'associate_cens' to be a list")
        pulumi.set(__self__, "associate_cens", associate_cens)
        if bgp_asn and not isinstance(bgp_asn, int):
            raise TypeError("Expected argument 'bgp_asn' to be a int")
        pulumi.set(__self__, "bgp_asn", bgp_asn)
        if business_status and not isinstance(business_status, str):
            raise TypeError("Expected argument 'business_status' to be a str")
        pulumi.set(__self__, "business_status", business_status)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if deleted_time and not isinstance(deleted_time, str):
            raise TypeError("Expected argument 'deleted_time' to be a str")
        pulumi.set(__self__, "deleted_time", deleted_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if direct_connect_gateway_id and not isinstance(direct_connect_gateway_id, str):
            raise TypeError("Expected argument 'direct_connect_gateway_id' to be a str")
        pulumi.set(__self__, "direct_connect_gateway_id", direct_connect_gateway_id)
        if direct_connect_gateway_name and not isinstance(direct_connect_gateway_name, str):
            raise TypeError("Expected argument 'direct_connect_gateway_name' to be a str")
        pulumi.set(__self__, "direct_connect_gateway_name", direct_connect_gateway_name)
        if enable_ipv6 and not isinstance(enable_ipv6, bool):
            raise TypeError("Expected argument 'enable_ipv6' to be a bool")
        pulumi.set(__self__, "enable_ipv6", enable_ipv6)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lock_reason and not isinstance(lock_reason, str):
            raise TypeError("Expected argument 'lock_reason' to be a str")
        pulumi.set(__self__, "lock_reason", lock_reason)
        if overdue_time and not isinstance(overdue_time, str):
            raise TypeError("Expected argument 'overdue_time' to be a str")
        pulumi.set(__self__, "overdue_time", overdue_time)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        专线网关所属账号的ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="associateCens")
    def associate_cens(self) -> Sequence['outputs.GetDirectConnectGatewayAssociateCenResult']:
        """
        关联的CEN信息。
        """
        return pulumi.get(self, "associate_cens")

    @property
    @pulumi.getter(name="bgpAsn")
    def bgp_asn(self) -> builtins.int:
        """
        专线网关的ASN（Autonomous System Number）。专线网关ASN有效范围为：137718、64512 ～ 65534 、4200000000 ～ 4294967294，其中137718为火山引擎的ASN。如果专线网关仅在普通场景下使用（如本地IDC通过专线连接访问单个云上VPC资源），请使用火山引擎ASN（137718）。如果专线网关在特殊场景下使用（如单个IDC通过专线连接访问多个云企业网），每个专线网关均要自定义ASN且避免使用火山引擎ASN（137718），确保不同专线网关的ASN不重复。
        """
        return pulumi.get(self, "bgp_asn")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> builtins.str:
        """
        专线网关是否被锁定。Normal：正常。FinancialLocked：被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建专线网关的时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> builtins.str:
        """
        预期资源强制回收时间。仅当资源因为欠费冻结，此参数才会有返回值，否则均返回空值。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        专线网关的描述信息。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、空格（ ）、下划线（_）、中划线（-）、等号（=）、英文逗号（,）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="directConnectGatewayId")
    def direct_connect_gateway_id(self) -> builtins.str:
        """
        专线网关的ID。
        """
        return pulumi.get(self, "direct_connect_gateway_id")

    @property
    @pulumi.getter(name="directConnectGatewayName")
    def direct_connect_gateway_name(self) -> builtins.str:
        """
        专线网关的名称。以中文、字母、数字开头，只能包含中文、字母、数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为专线网关的ID。
        """
        return pulumi.get(self, "direct_connect_gateway_name")

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> builtins.bool:
        """
        是否支持IPv6。true：支持。false：不支持。
        """
        return pulumi.get(self, "enable_ipv6")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> builtins.str:
        """
        专线网关被锁定的原因。unlock：解锁。financial：因欠费被锁定。security：因安全被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> builtins.str:
        """
        资源冻结时间。仅当资源因为欠费冻结，此参数才会有返回值，否则均返回空值。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        专线网关所属的项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        专线网关的状态。Creating：创建中。Deleting：删除中。Pending：配置中。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetDirectConnectGatewayTagResult']:
        """
        专线网关已添加的全部标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新专线网关的时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetDirectConnectGatewayResult(GetDirectConnectGatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDirectConnectGatewayResult(
            account_id=self.account_id,
            associate_cens=self.associate_cens,
            bgp_asn=self.bgp_asn,
            business_status=self.business_status,
            created_time=self.created_time,
            deleted_time=self.deleted_time,
            description=self.description,
            direct_connect_gateway_id=self.direct_connect_gateway_id,
            direct_connect_gateway_name=self.direct_connect_gateway_name,
            enable_ipv6=self.enable_ipv6,
            id=self.id,
            lock_reason=self.lock_reason,
            overdue_time=self.overdue_time,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time)


def get_direct_connect_gateway(id: Optional[builtins.str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDirectConnectGatewayResult:
    """
    Data Source schema for Byteplus::DirectConnect::DirectConnectGateway


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:directconnect/getDirectConnectGateway:getDirectConnectGateway', __args__, opts=opts, typ=GetDirectConnectGatewayResult).value

    return AwaitableGetDirectConnectGatewayResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        associate_cens=pulumi.get(__ret__, 'associate_cens'),
        bgp_asn=pulumi.get(__ret__, 'bgp_asn'),
        business_status=pulumi.get(__ret__, 'business_status'),
        created_time=pulumi.get(__ret__, 'created_time'),
        deleted_time=pulumi.get(__ret__, 'deleted_time'),
        description=pulumi.get(__ret__, 'description'),
        direct_connect_gateway_id=pulumi.get(__ret__, 'direct_connect_gateway_id'),
        direct_connect_gateway_name=pulumi.get(__ret__, 'direct_connect_gateway_name'),
        enable_ipv6=pulumi.get(__ret__, 'enable_ipv6'),
        id=pulumi.get(__ret__, 'id'),
        lock_reason=pulumi.get(__ret__, 'lock_reason'),
        overdue_time=pulumi.get(__ret__, 'overdue_time'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_direct_connect_gateway_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDirectConnectGatewayResult]:
    """
    Data Source schema for Byteplus::DirectConnect::DirectConnectGateway


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:directconnect/getDirectConnectGateway:getDirectConnectGateway', __args__, opts=opts, typ=GetDirectConnectGatewayResult)
    return __ret__.apply(lambda __response__: GetDirectConnectGatewayResult(
        account_id=pulumi.get(__response__, 'account_id'),
        associate_cens=pulumi.get(__response__, 'associate_cens'),
        bgp_asn=pulumi.get(__response__, 'bgp_asn'),
        business_status=pulumi.get(__response__, 'business_status'),
        created_time=pulumi.get(__response__, 'created_time'),
        deleted_time=pulumi.get(__response__, 'deleted_time'),
        description=pulumi.get(__response__, 'description'),
        direct_connect_gateway_id=pulumi.get(__response__, 'direct_connect_gateway_id'),
        direct_connect_gateway_name=pulumi.get(__response__, 'direct_connect_gateway_name'),
        enable_ipv6=pulumi.get(__response__, 'enable_ipv6'),
        id=pulumi.get(__response__, 'id'),
        lock_reason=pulumi.get(__response__, 'lock_reason'),
        overdue_time=pulumi.get(__response__, 'overdue_time'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'RegistryProxyCache',
    'RegistryStatus',
    'RegistryTag',
    'GetRegistryProxyCacheResult',
    'GetRegistryStatusResult',
    'GetRegistryTagResult',
]

@pulumi.output_type
class RegistryProxyCache(dict):
    def __init__(__self__, *,
                 type: Optional[builtins.str] = None):
        """
        :param builtins.str type: ProxyCache支持的镜像仓库实例类型，参数值说明如下：DockerHub：dockerhub 镜像仓库。
        """
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        ProxyCache支持的镜像仓库实例类型，参数值说明如下：DockerHub：dockerhub 镜像仓库。
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class RegistryStatus(dict):
    def __init__(__self__, *,
                 conditions: Optional[Sequence[builtins.str]] = None,
                 phase: Optional[builtins.str] = None):
        """
        :param Sequence[builtins.str] conditions: Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        :param builtins.str phase: Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        """
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if phase is not None:
            pulumi.set(__self__, "phase", phase)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[Sequence[builtins.str]]:
        """
        Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter
    def phase(self) -> Optional[builtins.str]:
        """
        Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        """
        return pulumi.get(self, "phase")


@pulumi.output_type
class RegistryTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签的 Key 值。
        :param builtins.str value: 标签的 Value 值列表。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签的 Key 值。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签的 Value 值列表。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetRegistryProxyCacheResult(dict):
    def __init__(__self__, *,
                 type: builtins.str):
        """
        :param builtins.str type: ProxyCache支持的镜像仓库实例类型，参数值说明如下：DockerHub：dockerhub 镜像仓库。
        """
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        ProxyCache支持的镜像仓库实例类型，参数值说明如下：DockerHub：dockerhub 镜像仓库。
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetRegistryStatusResult(dict):
    def __init__(__self__, *,
                 conditions: Sequence[builtins.str],
                 phase: builtins.str):
        """
        :param Sequence[builtins.str] conditions: Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        :param builtins.str phase: Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        """
        pulumi.set(__self__, "conditions", conditions)
        pulumi.set(__self__, "phase", phase)

    @property
    @pulumi.getter
    def conditions(self) -> Sequence[builtins.str]:
        """
        Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter
    def phase(self) -> builtins.str:
        """
        Creating, [ Progressing ] ：创建中。Running, [ Ok ] ：运行中。Running, [ Degraded ] ：运行中。Stopped, [ Balance ] ： 欠费关停。Stopped, [ Released ] ：待回收。Stopped, [ Released, Balance ] ：欠费关停。Starting, [ Progressing ] ：启动中。Deleting, [ Progressing ] ：销毁中。Failed, [ Unknown ] ：异常。
        """
        return pulumi.get(self, "phase")


@pulumi.output_type
class GetRegistryTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签的 Key 值。
        :param builtins.str value: 标签的 Value 值列表。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签的 Key 值。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签的 Value 值列表。
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RuleArgs', 'Rule']

@pulumi.input_type
class RuleArgs:
    def __init__(__self__, *,
                 effect_end_at: pulumi.Input[builtins.str],
                 effect_start_at: pulumi.Input[builtins.str],
                 enable_state: pulumi.Input[builtins.str],
                 evaluation_count: pulumi.Input[builtins.int],
                 level: pulumi.Input[builtins.str],
                 namespace: pulumi.Input[builtins.str],
                 rule_name: pulumi.Input[builtins.str],
                 rule_type: pulumi.Input[builtins.str],
                 silence_time: pulumi.Input[builtins.int],
                 sub_namespace: pulumi.Input[builtins.str],
                 alert_methods: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 condition_operator: Optional[pulumi.Input[builtins.str]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input['RuleConditionArgs']]]] = None,
                 contact_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dimension_conditions: Optional[pulumi.Input['RuleDimensionConditionsArgs']] = None,
                 level_conditions: Optional[pulumi.Input[Sequence[pulumi.Input['RuleLevelConditionArgs']]]] = None,
                 multiple_conditions: Optional[pulumi.Input[builtins.bool]] = None,
                 no_data: Optional[pulumi.Input['RuleNoDataArgs']] = None,
                 notification_id: Optional[pulumi.Input[builtins.str]] = None,
                 notify_templates: Optional[pulumi.Input[Sequence[pulumi.Input['RuleNotifyTemplateArgs']]]] = None,
                 original_dimensions: Optional[pulumi.Input['RuleOriginalDimensionsArgs']] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 recovery_notify: Optional[pulumi.Input['RuleRecoveryNotifyArgs']] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['RuleTagArgs']]]] = None,
                 webhook: Optional[pulumi.Input[builtins.str]] = None,
                 webhook_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Rule resource.
        :param pulumi.Input[builtins.str] effect_end_at: 策略生效的截止时间，格式为HH:MM。
        :param pulumi.Input[builtins.str] effect_start_at: 告警策略生效的开始时间，格式为HH:MM。
        :param pulumi.Input[builtins.str] enable_state: 告警策略的开启状态。,enable：开启,disable：禁用
        :param pulumi.Input[builtins.int] evaluation_count: 触发告警需要持续的周期。单位为分钟。
        :param pulumi.Input[builtins.str] level: 告警级别。critical：严重,warning：警告,notice：通知
        :param pulumi.Input[builtins.str] namespace: 监控指标所属的云产品。详情请参见 云产品监控指标 下各产品的 Namespace。
        :param pulumi.Input[builtins.str] rule_name: 告警策略名称。
        :param pulumi.Input[builtins.str] rule_type: 告警策略的类型。static：手动选择。dynamic：通过资源名称、项目和标签选择。
        :param pulumi.Input[builtins.int] silence_time: 告警发送周期。单位为分钟。支持配置为 5、10、15、30、60、180、360、720、1440。
        :param pulumi.Input[builtins.str] sub_namespace: 此策略引用的指标所属的维度。详情请参见 云产品监控指标 下各产品的 SubNamespace。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] alert_methods: 告警通知的方式。Email：邮件 Phone：电话 SMS：短信 Webhook：告警回调。
        :param pulumi.Input[builtins.str] condition_operator: 多指标判定条件。&&：多个指标同时成立才判定为触发告警,||：任意指标满足条件触发判定为告警。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] contact_group_ids: 告警策略绑定的告警通知组 ID。
        :param pulumi.Input[builtins.str] description: 告警策略描述信息。
        :param pulumi.Input['RuleDimensionConditionsArgs'] dimension_conditions: Dimension 配置。
        :param pulumi.Input[builtins.bool] multiple_conditions: 告警策略是否用多指标。true：多指标,false：单指标（默认）。
        :param pulumi.Input['RuleNoDataArgs'] no_data: 无数据告警。
        :param pulumi.Input[builtins.str] notification_id: 通知策略 ID。
        :param pulumi.Input['RuleOriginalDimensionsArgs'] original_dimensions: 告警策略检测的资源 ID。
        :param pulumi.Input[builtins.str] project_name: 告警策略所属项目。
        :param pulumi.Input['RuleRecoveryNotifyArgs'] recovery_notify: 告警恢复通知。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions: 云产品所属可用区 ID。
        :param pulumi.Input[builtins.str] webhook: 告警策略绑定的告警回调 URL 地址。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] webhook_ids: 告警发生时告警回调 ID 列表。
        """
        pulumi.set(__self__, "effect_end_at", effect_end_at)
        pulumi.set(__self__, "effect_start_at", effect_start_at)
        pulumi.set(__self__, "enable_state", enable_state)
        pulumi.set(__self__, "evaluation_count", evaluation_count)
        pulumi.set(__self__, "level", level)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "rule_name", rule_name)
        pulumi.set(__self__, "rule_type", rule_type)
        pulumi.set(__self__, "silence_time", silence_time)
        pulumi.set(__self__, "sub_namespace", sub_namespace)
        if alert_methods is not None:
            pulumi.set(__self__, "alert_methods", alert_methods)
        if condition_operator is not None:
            pulumi.set(__self__, "condition_operator", condition_operator)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if contact_group_ids is not None:
            pulumi.set(__self__, "contact_group_ids", contact_group_ids)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dimension_conditions is not None:
            pulumi.set(__self__, "dimension_conditions", dimension_conditions)
        if level_conditions is not None:
            pulumi.set(__self__, "level_conditions", level_conditions)
        if multiple_conditions is not None:
            pulumi.set(__self__, "multiple_conditions", multiple_conditions)
        if no_data is not None:
            pulumi.set(__self__, "no_data", no_data)
        if notification_id is not None:
            pulumi.set(__self__, "notification_id", notification_id)
        if notify_templates is not None:
            pulumi.set(__self__, "notify_templates", notify_templates)
        if original_dimensions is not None:
            pulumi.set(__self__, "original_dimensions", original_dimensions)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if recovery_notify is not None:
            pulumi.set(__self__, "recovery_notify", recovery_notify)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if webhook is not None:
            pulumi.set(__self__, "webhook", webhook)
        if webhook_ids is not None:
            pulumi.set(__self__, "webhook_ids", webhook_ids)

    @property
    @pulumi.getter(name="effectEndAt")
    def effect_end_at(self) -> pulumi.Input[builtins.str]:
        """
        策略生效的截止时间，格式为HH:MM。
        """
        return pulumi.get(self, "effect_end_at")

    @effect_end_at.setter
    def effect_end_at(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "effect_end_at", value)

    @property
    @pulumi.getter(name="effectStartAt")
    def effect_start_at(self) -> pulumi.Input[builtins.str]:
        """
        告警策略生效的开始时间，格式为HH:MM。
        """
        return pulumi.get(self, "effect_start_at")

    @effect_start_at.setter
    def effect_start_at(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "effect_start_at", value)

    @property
    @pulumi.getter(name="enableState")
    def enable_state(self) -> pulumi.Input[builtins.str]:
        """
        告警策略的开启状态。,enable：开启,disable：禁用
        """
        return pulumi.get(self, "enable_state")

    @enable_state.setter
    def enable_state(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "enable_state", value)

    @property
    @pulumi.getter(name="evaluationCount")
    def evaluation_count(self) -> pulumi.Input[builtins.int]:
        """
        触发告警需要持续的周期。单位为分钟。
        """
        return pulumi.get(self, "evaluation_count")

    @evaluation_count.setter
    def evaluation_count(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "evaluation_count", value)

    @property
    @pulumi.getter
    def level(self) -> pulumi.Input[builtins.str]:
        """
        告警级别。critical：严重,warning：警告,notice：通知
        """
        return pulumi.get(self, "level")

    @level.setter
    def level(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "level", value)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[builtins.str]:
        """
        监控指标所属的云产品。详情请参见 云产品监控指标 下各产品的 Namespace。
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Input[builtins.str]:
        """
        告警策略名称。
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> pulumi.Input[builtins.str]:
        """
        告警策略的类型。static：手动选择。dynamic：通过资源名称、项目和标签选择。
        """
        return pulumi.get(self, "rule_type")

    @rule_type.setter
    def rule_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "rule_type", value)

    @property
    @pulumi.getter(name="silenceTime")
    def silence_time(self) -> pulumi.Input[builtins.int]:
        """
        告警发送周期。单位为分钟。支持配置为 5、10、15、30、60、180、360、720、1440。
        """
        return pulumi.get(self, "silence_time")

    @silence_time.setter
    def silence_time(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "silence_time", value)

    @property
    @pulumi.getter(name="subNamespace")
    def sub_namespace(self) -> pulumi.Input[builtins.str]:
        """
        此策略引用的指标所属的维度。详情请参见 云产品监控指标 下各产品的 SubNamespace。
        """
        return pulumi.get(self, "sub_namespace")

    @sub_namespace.setter
    def sub_namespace(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "sub_namespace", value)

    @property
    @pulumi.getter(name="alertMethods")
    def alert_methods(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        告警通知的方式。Email：邮件 Phone：电话 SMS：短信 Webhook：告警回调。
        """
        return pulumi.get(self, "alert_methods")

    @alert_methods.setter
    def alert_methods(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "alert_methods", value)

    @property
    @pulumi.getter(name="conditionOperator")
    def condition_operator(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        多指标判定条件。&&：多个指标同时成立才判定为触发告警,||：任意指标满足条件触发判定为告警。
        """
        return pulumi.get(self, "condition_operator")

    @condition_operator.setter
    def condition_operator(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "condition_operator", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleConditionArgs']]]]:
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleConditionArgs']]]]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter(name="contactGroupIds")
    def contact_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        告警策略绑定的告警通知组 ID。
        """
        return pulumi.get(self, "contact_group_ids")

    @contact_group_ids.setter
    def contact_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "contact_group_ids", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dimensionConditions")
    def dimension_conditions(self) -> Optional[pulumi.Input['RuleDimensionConditionsArgs']]:
        """
        Dimension 配置。
        """
        return pulumi.get(self, "dimension_conditions")

    @dimension_conditions.setter
    def dimension_conditions(self, value: Optional[pulumi.Input['RuleDimensionConditionsArgs']]):
        pulumi.set(self, "dimension_conditions", value)

    @property
    @pulumi.getter(name="levelConditions")
    def level_conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleLevelConditionArgs']]]]:
        return pulumi.get(self, "level_conditions")

    @level_conditions.setter
    def level_conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleLevelConditionArgs']]]]):
        pulumi.set(self, "level_conditions", value)

    @property
    @pulumi.getter(name="multipleConditions")
    def multiple_conditions(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        告警策略是否用多指标。true：多指标,false：单指标（默认）。
        """
        return pulumi.get(self, "multiple_conditions")

    @multiple_conditions.setter
    def multiple_conditions(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "multiple_conditions", value)

    @property
    @pulumi.getter(name="noData")
    def no_data(self) -> Optional[pulumi.Input['RuleNoDataArgs']]:
        """
        无数据告警。
        """
        return pulumi.get(self, "no_data")

    @no_data.setter
    def no_data(self, value: Optional[pulumi.Input['RuleNoDataArgs']]):
        pulumi.set(self, "no_data", value)

    @property
    @pulumi.getter(name="notificationId")
    def notification_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        通知策略 ID。
        """
        return pulumi.get(self, "notification_id")

    @notification_id.setter
    def notification_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "notification_id", value)

    @property
    @pulumi.getter(name="notifyTemplates")
    def notify_templates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleNotifyTemplateArgs']]]]:
        return pulumi.get(self, "notify_templates")

    @notify_templates.setter
    def notify_templates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleNotifyTemplateArgs']]]]):
        pulumi.set(self, "notify_templates", value)

    @property
    @pulumi.getter(name="originalDimensions")
    def original_dimensions(self) -> Optional[pulumi.Input['RuleOriginalDimensionsArgs']]:
        """
        告警策略检测的资源 ID。
        """
        return pulumi.get(self, "original_dimensions")

    @original_dimensions.setter
    def original_dimensions(self, value: Optional[pulumi.Input['RuleOriginalDimensionsArgs']]):
        pulumi.set(self, "original_dimensions", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略所属项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="recoveryNotify")
    def recovery_notify(self) -> Optional[pulumi.Input['RuleRecoveryNotifyArgs']]:
        """
        告警恢复通知。
        """
        return pulumi.get(self, "recovery_notify")

    @recovery_notify.setter
    def recovery_notify(self, value: Optional[pulumi.Input['RuleRecoveryNotifyArgs']]):
        pulumi.set(self, "recovery_notify", value)

    @property
    @pulumi.getter
    def regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        云产品所属可用区 ID。
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def webhook(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略绑定的告警回调 URL 地址。
        """
        return pulumi.get(self, "webhook")

    @webhook.setter
    def webhook(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "webhook", value)

    @property
    @pulumi.getter(name="webhookIds")
    def webhook_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        告警发生时告警回调 ID 列表。
        """
        return pulumi.get(self, "webhook_ids")

    @webhook_ids.setter
    def webhook_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "webhook_ids", value)


@pulumi.input_type
class _RuleState:
    def __init__(__self__, *,
                 alert_methods: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 alert_state: Optional[pulumi.Input[builtins.str]] = None,
                 condition_operator: Optional[pulumi.Input[builtins.str]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input['RuleConditionArgs']]]] = None,
                 contact_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dimension_conditions: Optional[pulumi.Input['RuleDimensionConditionsArgs']] = None,
                 effect_end_at: Optional[pulumi.Input[builtins.str]] = None,
                 effect_start_at: Optional[pulumi.Input[builtins.str]] = None,
                 enable_state: Optional[pulumi.Input[builtins.str]] = None,
                 evaluation_count: Optional[pulumi.Input[builtins.int]] = None,
                 level: Optional[pulumi.Input[builtins.str]] = None,
                 level_conditions: Optional[pulumi.Input[Sequence[pulumi.Input['RuleLevelConditionArgs']]]] = None,
                 multiple_conditions: Optional[pulumi.Input[builtins.bool]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 no_data: Optional[pulumi.Input['RuleNoDataArgs']] = None,
                 notification_id: Optional[pulumi.Input[builtins.str]] = None,
                 notify_templates: Optional[pulumi.Input[Sequence[pulumi.Input['RuleNotifyTemplateArgs']]]] = None,
                 original_dimensions: Optional[pulumi.Input['RuleOriginalDimensionsArgs']] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 recovery_notify: Optional[pulumi.Input['RuleRecoveryNotifyArgs']] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 rule_id: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 rule_type: Optional[pulumi.Input[builtins.str]] = None,
                 silence_time: Optional[pulumi.Input[builtins.int]] = None,
                 sub_namespace: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['RuleTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None,
                 webhook: Optional[pulumi.Input[builtins.str]] = None,
                 webhook_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Rule resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] alert_methods: 告警通知的方式。Email：邮件 Phone：电话 SMS：短信 Webhook：告警回调。
        :param pulumi.Input[builtins.str] alert_state: 告警状态。 alerting：告警中 normal：正常。
        :param pulumi.Input[builtins.str] condition_operator: 多指标判定条件。&&：多个指标同时成立才判定为触发告警,||：任意指标满足条件触发判定为告警。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] contact_group_ids: 告警策略绑定的告警通知组 ID。
        :param pulumi.Input[builtins.str] created_at: 告警策略创建时间，时间戳格式。
        :param pulumi.Input[builtins.str] description: 告警策略描述信息。
        :param pulumi.Input['RuleDimensionConditionsArgs'] dimension_conditions: Dimension 配置。
        :param pulumi.Input[builtins.str] effect_end_at: 策略生效的截止时间，格式为HH:MM。
        :param pulumi.Input[builtins.str] effect_start_at: 告警策略生效的开始时间，格式为HH:MM。
        :param pulumi.Input[builtins.str] enable_state: 告警策略的开启状态。,enable：开启,disable：禁用
        :param pulumi.Input[builtins.int] evaluation_count: 触发告警需要持续的周期。单位为分钟。
        :param pulumi.Input[builtins.str] level: 告警级别。critical：严重,warning：警告,notice：通知
        :param pulumi.Input[builtins.bool] multiple_conditions: 告警策略是否用多指标。true：多指标,false：单指标（默认）。
        :param pulumi.Input[builtins.str] namespace: 监控指标所属的云产品。详情请参见 云产品监控指标 下各产品的 Namespace。
        :param pulumi.Input['RuleNoDataArgs'] no_data: 无数据告警。
        :param pulumi.Input[builtins.str] notification_id: 通知策略 ID。
        :param pulumi.Input['RuleOriginalDimensionsArgs'] original_dimensions: 告警策略检测的资源 ID。
        :param pulumi.Input[builtins.str] project_name: 告警策略所属项目。
        :param pulumi.Input['RuleRecoveryNotifyArgs'] recovery_notify: 告警恢复通知。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions: 云产品所属可用区 ID。
        :param pulumi.Input[builtins.str] resource_type: 告警策略检测的资源类型。
        :param pulumi.Input[builtins.str] rule_id: 告警策略 ID。
        :param pulumi.Input[builtins.str] rule_name: 告警策略名称。
        :param pulumi.Input[builtins.str] rule_type: 告警策略的类型。static：手动选择。dynamic：通过资源名称、项目和标签选择。
        :param pulumi.Input[builtins.int] silence_time: 告警发送周期。单位为分钟。支持配置为 5、10、15、30、60、180、360、720、1440。
        :param pulumi.Input[builtins.str] sub_namespace: 此策略引用的指标所属的维度。详情请参见 云产品监控指标 下各产品的 SubNamespace。
        :param pulumi.Input[builtins.str] updated_at: 告警策略更新时间，时间戳格式。
        :param pulumi.Input[builtins.str] webhook: 告警策略绑定的告警回调 URL 地址。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] webhook_ids: 告警发生时告警回调 ID 列表。
        """
        if alert_methods is not None:
            pulumi.set(__self__, "alert_methods", alert_methods)
        if alert_state is not None:
            pulumi.set(__self__, "alert_state", alert_state)
        if condition_operator is not None:
            pulumi.set(__self__, "condition_operator", condition_operator)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if contact_group_ids is not None:
            pulumi.set(__self__, "contact_group_ids", contact_group_ids)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dimension_conditions is not None:
            pulumi.set(__self__, "dimension_conditions", dimension_conditions)
        if effect_end_at is not None:
            pulumi.set(__self__, "effect_end_at", effect_end_at)
        if effect_start_at is not None:
            pulumi.set(__self__, "effect_start_at", effect_start_at)
        if enable_state is not None:
            pulumi.set(__self__, "enable_state", enable_state)
        if evaluation_count is not None:
            pulumi.set(__self__, "evaluation_count", evaluation_count)
        if level is not None:
            pulumi.set(__self__, "level", level)
        if level_conditions is not None:
            pulumi.set(__self__, "level_conditions", level_conditions)
        if multiple_conditions is not None:
            pulumi.set(__self__, "multiple_conditions", multiple_conditions)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if no_data is not None:
            pulumi.set(__self__, "no_data", no_data)
        if notification_id is not None:
            pulumi.set(__self__, "notification_id", notification_id)
        if notify_templates is not None:
            pulumi.set(__self__, "notify_templates", notify_templates)
        if original_dimensions is not None:
            pulumi.set(__self__, "original_dimensions", original_dimensions)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if recovery_notify is not None:
            pulumi.set(__self__, "recovery_notify", recovery_notify)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if rule_id is not None:
            pulumi.set(__self__, "rule_id", rule_id)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if rule_type is not None:
            pulumi.set(__self__, "rule_type", rule_type)
        if silence_time is not None:
            pulumi.set(__self__, "silence_time", silence_time)
        if sub_namespace is not None:
            pulumi.set(__self__, "sub_namespace", sub_namespace)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if webhook is not None:
            pulumi.set(__self__, "webhook", webhook)
        if webhook_ids is not None:
            pulumi.set(__self__, "webhook_ids", webhook_ids)

    @property
    @pulumi.getter(name="alertMethods")
    def alert_methods(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        告警通知的方式。Email：邮件 Phone：电话 SMS：短信 Webhook：告警回调。
        """
        return pulumi.get(self, "alert_methods")

    @alert_methods.setter
    def alert_methods(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "alert_methods", value)

    @property
    @pulumi.getter(name="alertState")
    def alert_state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警状态。 alerting：告警中 normal：正常。
        """
        return pulumi.get(self, "alert_state")

    @alert_state.setter
    def alert_state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alert_state", value)

    @property
    @pulumi.getter(name="conditionOperator")
    def condition_operator(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        多指标判定条件。&&：多个指标同时成立才判定为触发告警,||：任意指标满足条件触发判定为告警。
        """
        return pulumi.get(self, "condition_operator")

    @condition_operator.setter
    def condition_operator(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "condition_operator", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleConditionArgs']]]]:
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleConditionArgs']]]]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter(name="contactGroupIds")
    def contact_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        告警策略绑定的告警通知组 ID。
        """
        return pulumi.get(self, "contact_group_ids")

    @contact_group_ids.setter
    def contact_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "contact_group_ids", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略创建时间，时间戳格式。
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dimensionConditions")
    def dimension_conditions(self) -> Optional[pulumi.Input['RuleDimensionConditionsArgs']]:
        """
        Dimension 配置。
        """
        return pulumi.get(self, "dimension_conditions")

    @dimension_conditions.setter
    def dimension_conditions(self, value: Optional[pulumi.Input['RuleDimensionConditionsArgs']]):
        pulumi.set(self, "dimension_conditions", value)

    @property
    @pulumi.getter(name="effectEndAt")
    def effect_end_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        策略生效的截止时间，格式为HH:MM。
        """
        return pulumi.get(self, "effect_end_at")

    @effect_end_at.setter
    def effect_end_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "effect_end_at", value)

    @property
    @pulumi.getter(name="effectStartAt")
    def effect_start_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略生效的开始时间，格式为HH:MM。
        """
        return pulumi.get(self, "effect_start_at")

    @effect_start_at.setter
    def effect_start_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "effect_start_at", value)

    @property
    @pulumi.getter(name="enableState")
    def enable_state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略的开启状态。,enable：开启,disable：禁用
        """
        return pulumi.get(self, "enable_state")

    @enable_state.setter
    def enable_state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "enable_state", value)

    @property
    @pulumi.getter(name="evaluationCount")
    def evaluation_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        触发告警需要持续的周期。单位为分钟。
        """
        return pulumi.get(self, "evaluation_count")

    @evaluation_count.setter
    def evaluation_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "evaluation_count", value)

    @property
    @pulumi.getter
    def level(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警级别。critical：严重,warning：警告,notice：通知
        """
        return pulumi.get(self, "level")

    @level.setter
    def level(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "level", value)

    @property
    @pulumi.getter(name="levelConditions")
    def level_conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleLevelConditionArgs']]]]:
        return pulumi.get(self, "level_conditions")

    @level_conditions.setter
    def level_conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleLevelConditionArgs']]]]):
        pulumi.set(self, "level_conditions", value)

    @property
    @pulumi.getter(name="multipleConditions")
    def multiple_conditions(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        告警策略是否用多指标。true：多指标,false：单指标（默认）。
        """
        return pulumi.get(self, "multiple_conditions")

    @multiple_conditions.setter
    def multiple_conditions(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "multiple_conditions", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监控指标所属的云产品。详情请参见 云产品监控指标 下各产品的 Namespace。
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="noData")
    def no_data(self) -> Optional[pulumi.Input['RuleNoDataArgs']]:
        """
        无数据告警。
        """
        return pulumi.get(self, "no_data")

    @no_data.setter
    def no_data(self, value: Optional[pulumi.Input['RuleNoDataArgs']]):
        pulumi.set(self, "no_data", value)

    @property
    @pulumi.getter(name="notificationId")
    def notification_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        通知策略 ID。
        """
        return pulumi.get(self, "notification_id")

    @notification_id.setter
    def notification_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "notification_id", value)

    @property
    @pulumi.getter(name="notifyTemplates")
    def notify_templates(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleNotifyTemplateArgs']]]]:
        return pulumi.get(self, "notify_templates")

    @notify_templates.setter
    def notify_templates(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleNotifyTemplateArgs']]]]):
        pulumi.set(self, "notify_templates", value)

    @property
    @pulumi.getter(name="originalDimensions")
    def original_dimensions(self) -> Optional[pulumi.Input['RuleOriginalDimensionsArgs']]:
        """
        告警策略检测的资源 ID。
        """
        return pulumi.get(self, "original_dimensions")

    @original_dimensions.setter
    def original_dimensions(self, value: Optional[pulumi.Input['RuleOriginalDimensionsArgs']]):
        pulumi.set(self, "original_dimensions", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略所属项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="recoveryNotify")
    def recovery_notify(self) -> Optional[pulumi.Input['RuleRecoveryNotifyArgs']]:
        """
        告警恢复通知。
        """
        return pulumi.get(self, "recovery_notify")

    @recovery_notify.setter
    def recovery_notify(self, value: Optional[pulumi.Input['RuleRecoveryNotifyArgs']]):
        pulumi.set(self, "recovery_notify", value)

    @property
    @pulumi.getter
    def regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        云产品所属可用区 ID。
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略检测的资源类型。
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略 ID。
        """
        return pulumi.get(self, "rule_id")

    @rule_id.setter
    def rule_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_id", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略名称。
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略的类型。static：手动选择。dynamic：通过资源名称、项目和标签选择。
        """
        return pulumi.get(self, "rule_type")

    @rule_type.setter
    def rule_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_type", value)

    @property
    @pulumi.getter(name="silenceTime")
    def silence_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        告警发送周期。单位为分钟。支持配置为 5、10、15、30、60、180、360、720、1440。
        """
        return pulumi.get(self, "silence_time")

    @silence_time.setter
    def silence_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "silence_time", value)

    @property
    @pulumi.getter(name="subNamespace")
    def sub_namespace(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        此策略引用的指标所属的维度。详情请参见 云产品监控指标 下各产品的 SubNamespace。
        """
        return pulumi.get(self, "sub_namespace")

    @sub_namespace.setter
    def sub_namespace(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sub_namespace", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RuleTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RuleTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略更新时间，时间戳格式。
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def webhook(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        告警策略绑定的告警回调 URL 地址。
        """
        return pulumi.get(self, "webhook")

    @webhook.setter
    def webhook(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "webhook", value)

    @property
    @pulumi.getter(name="webhookIds")
    def webhook_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        告警发生时告警回调 ID 列表。
        """
        return pulumi.get(self, "webhook_ids")

    @webhook_ids.setter
    def webhook_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "webhook_ids", value)


@pulumi.type_token("bytepluscc:cloudmonitor/rule:Rule")
class Rule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alert_methods: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 condition_operator: Optional[pulumi.Input[builtins.str]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleConditionArgs', 'RuleConditionArgsDict']]]]] = None,
                 contact_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dimension_conditions: Optional[pulumi.Input[Union['RuleDimensionConditionsArgs', 'RuleDimensionConditionsArgsDict']]] = None,
                 effect_end_at: Optional[pulumi.Input[builtins.str]] = None,
                 effect_start_at: Optional[pulumi.Input[builtins.str]] = None,
                 enable_state: Optional[pulumi.Input[builtins.str]] = None,
                 evaluation_count: Optional[pulumi.Input[builtins.int]] = None,
                 level: Optional[pulumi.Input[builtins.str]] = None,
                 level_conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleLevelConditionArgs', 'RuleLevelConditionArgsDict']]]]] = None,
                 multiple_conditions: Optional[pulumi.Input[builtins.bool]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 no_data: Optional[pulumi.Input[Union['RuleNoDataArgs', 'RuleNoDataArgsDict']]] = None,
                 notification_id: Optional[pulumi.Input[builtins.str]] = None,
                 notify_templates: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleNotifyTemplateArgs', 'RuleNotifyTemplateArgsDict']]]]] = None,
                 original_dimensions: Optional[pulumi.Input[Union['RuleOriginalDimensionsArgs', 'RuleOriginalDimensionsArgsDict']]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 recovery_notify: Optional[pulumi.Input[Union['RuleRecoveryNotifyArgs', 'RuleRecoveryNotifyArgsDict']]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 rule_type: Optional[pulumi.Input[builtins.str]] = None,
                 silence_time: Optional[pulumi.Input[builtins.int]] = None,
                 sub_namespace: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleTagArgs', 'RuleTagArgsDict']]]]] = None,
                 webhook: Optional[pulumi.Input[builtins.str]] = None,
                 webhook_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        如果您需要监控某一云产品资源的数据状态，则可以创建云监控告警策略。当被监控的云产品资源数据达到告警的触发条件时，系统会通过您指定的方式推送告警通知，便于您及时发现存在异常数据的资源。

        ## Import

        ```sh
        $ pulumi import bytepluscc:cloudmonitor/rule:Rule example "rule_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] alert_methods: 告警通知的方式。Email：邮件 Phone：电话 SMS：短信 Webhook：告警回调。
        :param pulumi.Input[builtins.str] condition_operator: 多指标判定条件。&&：多个指标同时成立才判定为触发告警,||：任意指标满足条件触发判定为告警。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] contact_group_ids: 告警策略绑定的告警通知组 ID。
        :param pulumi.Input[builtins.str] description: 告警策略描述信息。
        :param pulumi.Input[Union['RuleDimensionConditionsArgs', 'RuleDimensionConditionsArgsDict']] dimension_conditions: Dimension 配置。
        :param pulumi.Input[builtins.str] effect_end_at: 策略生效的截止时间，格式为HH:MM。
        :param pulumi.Input[builtins.str] effect_start_at: 告警策略生效的开始时间，格式为HH:MM。
        :param pulumi.Input[builtins.str] enable_state: 告警策略的开启状态。,enable：开启,disable：禁用
        :param pulumi.Input[builtins.int] evaluation_count: 触发告警需要持续的周期。单位为分钟。
        :param pulumi.Input[builtins.str] level: 告警级别。critical：严重,warning：警告,notice：通知
        :param pulumi.Input[builtins.bool] multiple_conditions: 告警策略是否用多指标。true：多指标,false：单指标（默认）。
        :param pulumi.Input[builtins.str] namespace: 监控指标所属的云产品。详情请参见 云产品监控指标 下各产品的 Namespace。
        :param pulumi.Input[Union['RuleNoDataArgs', 'RuleNoDataArgsDict']] no_data: 无数据告警。
        :param pulumi.Input[builtins.str] notification_id: 通知策略 ID。
        :param pulumi.Input[Union['RuleOriginalDimensionsArgs', 'RuleOriginalDimensionsArgsDict']] original_dimensions: 告警策略检测的资源 ID。
        :param pulumi.Input[builtins.str] project_name: 告警策略所属项目。
        :param pulumi.Input[Union['RuleRecoveryNotifyArgs', 'RuleRecoveryNotifyArgsDict']] recovery_notify: 告警恢复通知。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions: 云产品所属可用区 ID。
        :param pulumi.Input[builtins.str] rule_name: 告警策略名称。
        :param pulumi.Input[builtins.str] rule_type: 告警策略的类型。static：手动选择。dynamic：通过资源名称、项目和标签选择。
        :param pulumi.Input[builtins.int] silence_time: 告警发送周期。单位为分钟。支持配置为 5、10、15、30、60、180、360、720、1440。
        :param pulumi.Input[builtins.str] sub_namespace: 此策略引用的指标所属的维度。详情请参见 云产品监控指标 下各产品的 SubNamespace。
        :param pulumi.Input[builtins.str] webhook: 告警策略绑定的告警回调 URL 地址。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] webhook_ids: 告警发生时告警回调 ID 列表。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        如果您需要监控某一云产品资源的数据状态，则可以创建云监控告警策略。当被监控的云产品资源数据达到告警的触发条件时，系统会通过您指定的方式推送告警通知，便于您及时发现存在异常数据的资源。

        ## Import

        ```sh
        $ pulumi import bytepluscc:cloudmonitor/rule:Rule example "rule_id"
        ```

        :param str resource_name: The name of the resource.
        :param RuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alert_methods: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 condition_operator: Optional[pulumi.Input[builtins.str]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleConditionArgs', 'RuleConditionArgsDict']]]]] = None,
                 contact_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dimension_conditions: Optional[pulumi.Input[Union['RuleDimensionConditionsArgs', 'RuleDimensionConditionsArgsDict']]] = None,
                 effect_end_at: Optional[pulumi.Input[builtins.str]] = None,
                 effect_start_at: Optional[pulumi.Input[builtins.str]] = None,
                 enable_state: Optional[pulumi.Input[builtins.str]] = None,
                 evaluation_count: Optional[pulumi.Input[builtins.int]] = None,
                 level: Optional[pulumi.Input[builtins.str]] = None,
                 level_conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleLevelConditionArgs', 'RuleLevelConditionArgsDict']]]]] = None,
                 multiple_conditions: Optional[pulumi.Input[builtins.bool]] = None,
                 namespace: Optional[pulumi.Input[builtins.str]] = None,
                 no_data: Optional[pulumi.Input[Union['RuleNoDataArgs', 'RuleNoDataArgsDict']]] = None,
                 notification_id: Optional[pulumi.Input[builtins.str]] = None,
                 notify_templates: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleNotifyTemplateArgs', 'RuleNotifyTemplateArgsDict']]]]] = None,
                 original_dimensions: Optional[pulumi.Input[Union['RuleOriginalDimensionsArgs', 'RuleOriginalDimensionsArgsDict']]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 recovery_notify: Optional[pulumi.Input[Union['RuleRecoveryNotifyArgs', 'RuleRecoveryNotifyArgsDict']]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 rule_type: Optional[pulumi.Input[builtins.str]] = None,
                 silence_time: Optional[pulumi.Input[builtins.int]] = None,
                 sub_namespace: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleTagArgs', 'RuleTagArgsDict']]]]] = None,
                 webhook: Optional[pulumi.Input[builtins.str]] = None,
                 webhook_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RuleArgs.__new__(RuleArgs)

            __props__.__dict__["alert_methods"] = alert_methods
            __props__.__dict__["condition_operator"] = condition_operator
            __props__.__dict__["conditions"] = conditions
            __props__.__dict__["contact_group_ids"] = contact_group_ids
            __props__.__dict__["description"] = description
            __props__.__dict__["dimension_conditions"] = dimension_conditions
            if effect_end_at is None and not opts.urn:
                raise TypeError("Missing required property 'effect_end_at'")
            __props__.__dict__["effect_end_at"] = effect_end_at
            if effect_start_at is None and not opts.urn:
                raise TypeError("Missing required property 'effect_start_at'")
            __props__.__dict__["effect_start_at"] = effect_start_at
            if enable_state is None and not opts.urn:
                raise TypeError("Missing required property 'enable_state'")
            __props__.__dict__["enable_state"] = enable_state
            if evaluation_count is None and not opts.urn:
                raise TypeError("Missing required property 'evaluation_count'")
            __props__.__dict__["evaluation_count"] = evaluation_count
            if level is None and not opts.urn:
                raise TypeError("Missing required property 'level'")
            __props__.__dict__["level"] = level
            __props__.__dict__["level_conditions"] = level_conditions
            __props__.__dict__["multiple_conditions"] = multiple_conditions
            if namespace is None and not opts.urn:
                raise TypeError("Missing required property 'namespace'")
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["no_data"] = no_data
            __props__.__dict__["notification_id"] = notification_id
            __props__.__dict__["notify_templates"] = notify_templates
            __props__.__dict__["original_dimensions"] = original_dimensions
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["recovery_notify"] = recovery_notify
            __props__.__dict__["regions"] = regions
            if rule_name is None and not opts.urn:
                raise TypeError("Missing required property 'rule_name'")
            __props__.__dict__["rule_name"] = rule_name
            if rule_type is None and not opts.urn:
                raise TypeError("Missing required property 'rule_type'")
            __props__.__dict__["rule_type"] = rule_type
            if silence_time is None and not opts.urn:
                raise TypeError("Missing required property 'silence_time'")
            __props__.__dict__["silence_time"] = silence_time
            if sub_namespace is None and not opts.urn:
                raise TypeError("Missing required property 'sub_namespace'")
            __props__.__dict__["sub_namespace"] = sub_namespace
            __props__.__dict__["tags"] = tags
            __props__.__dict__["webhook"] = webhook
            __props__.__dict__["webhook_ids"] = webhook_ids
            __props__.__dict__["alert_state"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["resource_type"] = None
            __props__.__dict__["rule_id"] = None
            __props__.__dict__["updated_at"] = None
        super(Rule, __self__).__init__(
            'bytepluscc:cloudmonitor/rule:Rule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alert_methods: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            alert_state: Optional[pulumi.Input[builtins.str]] = None,
            condition_operator: Optional[pulumi.Input[builtins.str]] = None,
            conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleConditionArgs', 'RuleConditionArgsDict']]]]] = None,
            contact_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            dimension_conditions: Optional[pulumi.Input[Union['RuleDimensionConditionsArgs', 'RuleDimensionConditionsArgsDict']]] = None,
            effect_end_at: Optional[pulumi.Input[builtins.str]] = None,
            effect_start_at: Optional[pulumi.Input[builtins.str]] = None,
            enable_state: Optional[pulumi.Input[builtins.str]] = None,
            evaluation_count: Optional[pulumi.Input[builtins.int]] = None,
            level: Optional[pulumi.Input[builtins.str]] = None,
            level_conditions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleLevelConditionArgs', 'RuleLevelConditionArgsDict']]]]] = None,
            multiple_conditions: Optional[pulumi.Input[builtins.bool]] = None,
            namespace: Optional[pulumi.Input[builtins.str]] = None,
            no_data: Optional[pulumi.Input[Union['RuleNoDataArgs', 'RuleNoDataArgsDict']]] = None,
            notification_id: Optional[pulumi.Input[builtins.str]] = None,
            notify_templates: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleNotifyTemplateArgs', 'RuleNotifyTemplateArgsDict']]]]] = None,
            original_dimensions: Optional[pulumi.Input[Union['RuleOriginalDimensionsArgs', 'RuleOriginalDimensionsArgsDict']]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            recovery_notify: Optional[pulumi.Input[Union['RuleRecoveryNotifyArgs', 'RuleRecoveryNotifyArgsDict']]] = None,
            regions: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            resource_type: Optional[pulumi.Input[builtins.str]] = None,
            rule_id: Optional[pulumi.Input[builtins.str]] = None,
            rule_name: Optional[pulumi.Input[builtins.str]] = None,
            rule_type: Optional[pulumi.Input[builtins.str]] = None,
            silence_time: Optional[pulumi.Input[builtins.int]] = None,
            sub_namespace: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RuleTagArgs', 'RuleTagArgsDict']]]]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None,
            webhook: Optional[pulumi.Input[builtins.str]] = None,
            webhook_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'Rule':
        """
        Get an existing Rule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] alert_methods: 告警通知的方式。Email：邮件 Phone：电话 SMS：短信 Webhook：告警回调。
        :param pulumi.Input[builtins.str] alert_state: 告警状态。 alerting：告警中 normal：正常。
        :param pulumi.Input[builtins.str] condition_operator: 多指标判定条件。&&：多个指标同时成立才判定为触发告警,||：任意指标满足条件触发判定为告警。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] contact_group_ids: 告警策略绑定的告警通知组 ID。
        :param pulumi.Input[builtins.str] created_at: 告警策略创建时间，时间戳格式。
        :param pulumi.Input[builtins.str] description: 告警策略描述信息。
        :param pulumi.Input[Union['RuleDimensionConditionsArgs', 'RuleDimensionConditionsArgsDict']] dimension_conditions: Dimension 配置。
        :param pulumi.Input[builtins.str] effect_end_at: 策略生效的截止时间，格式为HH:MM。
        :param pulumi.Input[builtins.str] effect_start_at: 告警策略生效的开始时间，格式为HH:MM。
        :param pulumi.Input[builtins.str] enable_state: 告警策略的开启状态。,enable：开启,disable：禁用
        :param pulumi.Input[builtins.int] evaluation_count: 触发告警需要持续的周期。单位为分钟。
        :param pulumi.Input[builtins.str] level: 告警级别。critical：严重,warning：警告,notice：通知
        :param pulumi.Input[builtins.bool] multiple_conditions: 告警策略是否用多指标。true：多指标,false：单指标（默认）。
        :param pulumi.Input[builtins.str] namespace: 监控指标所属的云产品。详情请参见 云产品监控指标 下各产品的 Namespace。
        :param pulumi.Input[Union['RuleNoDataArgs', 'RuleNoDataArgsDict']] no_data: 无数据告警。
        :param pulumi.Input[builtins.str] notification_id: 通知策略 ID。
        :param pulumi.Input[Union['RuleOriginalDimensionsArgs', 'RuleOriginalDimensionsArgsDict']] original_dimensions: 告警策略检测的资源 ID。
        :param pulumi.Input[builtins.str] project_name: 告警策略所属项目。
        :param pulumi.Input[Union['RuleRecoveryNotifyArgs', 'RuleRecoveryNotifyArgsDict']] recovery_notify: 告警恢复通知。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] regions: 云产品所属可用区 ID。
        :param pulumi.Input[builtins.str] resource_type: 告警策略检测的资源类型。
        :param pulumi.Input[builtins.str] rule_id: 告警策略 ID。
        :param pulumi.Input[builtins.str] rule_name: 告警策略名称。
        :param pulumi.Input[builtins.str] rule_type: 告警策略的类型。static：手动选择。dynamic：通过资源名称、项目和标签选择。
        :param pulumi.Input[builtins.int] silence_time: 告警发送周期。单位为分钟。支持配置为 5、10、15、30、60、180、360、720、1440。
        :param pulumi.Input[builtins.str] sub_namespace: 此策略引用的指标所属的维度。详情请参见 云产品监控指标 下各产品的 SubNamespace。
        :param pulumi.Input[builtins.str] updated_at: 告警策略更新时间，时间戳格式。
        :param pulumi.Input[builtins.str] webhook: 告警策略绑定的告警回调 URL 地址。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] webhook_ids: 告警发生时告警回调 ID 列表。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RuleState.__new__(_RuleState)

        __props__.__dict__["alert_methods"] = alert_methods
        __props__.__dict__["alert_state"] = alert_state
        __props__.__dict__["condition_operator"] = condition_operator
        __props__.__dict__["conditions"] = conditions
        __props__.__dict__["contact_group_ids"] = contact_group_ids
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["dimension_conditions"] = dimension_conditions
        __props__.__dict__["effect_end_at"] = effect_end_at
        __props__.__dict__["effect_start_at"] = effect_start_at
        __props__.__dict__["enable_state"] = enable_state
        __props__.__dict__["evaluation_count"] = evaluation_count
        __props__.__dict__["level"] = level
        __props__.__dict__["level_conditions"] = level_conditions
        __props__.__dict__["multiple_conditions"] = multiple_conditions
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["no_data"] = no_data
        __props__.__dict__["notification_id"] = notification_id
        __props__.__dict__["notify_templates"] = notify_templates
        __props__.__dict__["original_dimensions"] = original_dimensions
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["recovery_notify"] = recovery_notify
        __props__.__dict__["regions"] = regions
        __props__.__dict__["resource_type"] = resource_type
        __props__.__dict__["rule_id"] = rule_id
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["rule_type"] = rule_type
        __props__.__dict__["silence_time"] = silence_time
        __props__.__dict__["sub_namespace"] = sub_namespace
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["webhook"] = webhook
        __props__.__dict__["webhook_ids"] = webhook_ids
        return Rule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="alertMethods")
    def alert_methods(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        告警通知的方式。Email：邮件 Phone：电话 SMS：短信 Webhook：告警回调。
        """
        return pulumi.get(self, "alert_methods")

    @property
    @pulumi.getter(name="alertState")
    def alert_state(self) -> pulumi.Output[builtins.str]:
        """
        告警状态。 alerting：告警中 normal：正常。
        """
        return pulumi.get(self, "alert_state")

    @property
    @pulumi.getter(name="conditionOperator")
    def condition_operator(self) -> pulumi.Output[builtins.str]:
        """
        多指标判定条件。&&：多个指标同时成立才判定为触发告警,||：任意指标满足条件触发判定为告警。
        """
        return pulumi.get(self, "condition_operator")

    @property
    @pulumi.getter
    def conditions(self) -> pulumi.Output[Sequence['outputs.RuleCondition']]:
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter(name="contactGroupIds")
    def contact_group_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        告警策略绑定的告警通知组 ID。
        """
        return pulumi.get(self, "contact_group_ids")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        告警策略创建时间，时间戳格式。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        告警策略描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dimensionConditions")
    def dimension_conditions(self) -> pulumi.Output['outputs.RuleDimensionConditions']:
        """
        Dimension 配置。
        """
        return pulumi.get(self, "dimension_conditions")

    @property
    @pulumi.getter(name="effectEndAt")
    def effect_end_at(self) -> pulumi.Output[builtins.str]:
        """
        策略生效的截止时间，格式为HH:MM。
        """
        return pulumi.get(self, "effect_end_at")

    @property
    @pulumi.getter(name="effectStartAt")
    def effect_start_at(self) -> pulumi.Output[builtins.str]:
        """
        告警策略生效的开始时间，格式为HH:MM。
        """
        return pulumi.get(self, "effect_start_at")

    @property
    @pulumi.getter(name="enableState")
    def enable_state(self) -> pulumi.Output[builtins.str]:
        """
        告警策略的开启状态。,enable：开启,disable：禁用
        """
        return pulumi.get(self, "enable_state")

    @property
    @pulumi.getter(name="evaluationCount")
    def evaluation_count(self) -> pulumi.Output[builtins.int]:
        """
        触发告警需要持续的周期。单位为分钟。
        """
        return pulumi.get(self, "evaluation_count")

    @property
    @pulumi.getter
    def level(self) -> pulumi.Output[builtins.str]:
        """
        告警级别。critical：严重,warning：警告,notice：通知
        """
        return pulumi.get(self, "level")

    @property
    @pulumi.getter(name="levelConditions")
    def level_conditions(self) -> pulumi.Output[Sequence['outputs.RuleLevelCondition']]:
        return pulumi.get(self, "level_conditions")

    @property
    @pulumi.getter(name="multipleConditions")
    def multiple_conditions(self) -> pulumi.Output[builtins.bool]:
        """
        告警策略是否用多指标。true：多指标,false：单指标（默认）。
        """
        return pulumi.get(self, "multiple_conditions")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[builtins.str]:
        """
        监控指标所属的云产品。详情请参见 云产品监控指标 下各产品的 Namespace。
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="noData")
    def no_data(self) -> pulumi.Output['outputs.RuleNoData']:
        """
        无数据告警。
        """
        return pulumi.get(self, "no_data")

    @property
    @pulumi.getter(name="notificationId")
    def notification_id(self) -> pulumi.Output[builtins.str]:
        """
        通知策略 ID。
        """
        return pulumi.get(self, "notification_id")

    @property
    @pulumi.getter(name="notifyTemplates")
    def notify_templates(self) -> pulumi.Output[Sequence['outputs.RuleNotifyTemplate']]:
        return pulumi.get(self, "notify_templates")

    @property
    @pulumi.getter(name="originalDimensions")
    def original_dimensions(self) -> pulumi.Output['outputs.RuleOriginalDimensions']:
        """
        告警策略检测的资源 ID。
        """
        return pulumi.get(self, "original_dimensions")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        告警策略所属项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="recoveryNotify")
    def recovery_notify(self) -> pulumi.Output['outputs.RuleRecoveryNotify']:
        """
        告警恢复通知。
        """
        return pulumi.get(self, "recovery_notify")

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        云产品所属可用区 ID。
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> pulumi.Output[builtins.str]:
        """
        告警策略检测的资源类型。
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> pulumi.Output[builtins.str]:
        """
        告警策略 ID。
        """
        return pulumi.get(self, "rule_id")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[builtins.str]:
        """
        告警策略名称。
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> pulumi.Output[builtins.str]:
        """
        告警策略的类型。static：手动选择。dynamic：通过资源名称、项目和标签选择。
        """
        return pulumi.get(self, "rule_type")

    @property
    @pulumi.getter(name="silenceTime")
    def silence_time(self) -> pulumi.Output[builtins.int]:
        """
        告警发送周期。单位为分钟。支持配置为 5、10、15、30、60、180、360、720、1440。
        """
        return pulumi.get(self, "silence_time")

    @property
    @pulumi.getter(name="subNamespace")
    def sub_namespace(self) -> pulumi.Output[builtins.str]:
        """
        此策略引用的指标所属的维度。详情请参见 云产品监控指标 下各产品的 SubNamespace。
        """
        return pulumi.get(self, "sub_namespace")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.RuleTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        告警策略更新时间，时间戳格式。
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def webhook(self) -> pulumi.Output[builtins.str]:
        """
        告警策略绑定的告警回调 URL 地址。
        """
        return pulumi.get(self, "webhook")

    @property
    @pulumi.getter(name="webhookIds")
    def webhook_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        告警发生时告警回调 ID 列表。
        """
        return pulumi.get(self, "webhook_ids")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NlbListenerArgs', 'NlbListener']

@pulumi.input_type
class NlbListenerArgs:
    def __init__(__self__, *,
                 load_balancer_id: pulumi.Input[builtins.str],
                 port: pulumi.Input[builtins.int],
                 protocol: pulumi.Input[builtins.str],
                 server_group_id: pulumi.Input[builtins.str],
                 certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 connection_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 end_port: Optional[pulumi.Input[builtins.int]] = None,
                 healths: Optional[pulumi.Input[Sequence[pulumi.Input['NlbListenerHealthArgs']]]] = None,
                 listener_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_policy_id: Optional[pulumi.Input[builtins.str]] = None,
                 start_port: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NlbListenerTagArgs']]]] = None):
        """
        The set of arguments for constructing a NlbListener resource.
        :param pulumi.Input[builtins.str] load_balancer_id: 负载均衡实例ID。
        :param pulumi.Input[builtins.int] port: 监听器接收请求的端口，0表示启用全端口监听。
        :param pulumi.Input[builtins.str] protocol: 监听协议类型。TCP,UDP,TLS
        :param pulumi.Input[builtins.str] server_group_id: 监听器关联的服务器组ID。
        :param pulumi.Input[builtins.str] certificate_id: TLS监听器服务器证书的ID，仅支持传入证书中心 SSL 证书。。
        :param pulumi.Input[builtins.int] connection_timeout: 监听器的连接超时时间（秒）。
        :param pulumi.Input[builtins.str] description: 监听器描述信息。
        :param pulumi.Input[builtins.bool] enabled: 是否启用监听器。true：开启；false：关闭。
        :param pulumi.Input[builtins.int] end_port: 全端口监听的结束端口，仅当Port为0时有效。
        :param pulumi.Input[builtins.str] listener_name: 监听器名称。
        :param pulumi.Input[builtins.str] security_policy_id: TLS 安全策略ID，支持系统安全策略和自定义安全策略。系统安全策略取值：.tls*cipher*policy*1*0.tls*cipher*policy*1*1.tls*cipher*policy*1*2.tls*cipher*policy*1*2*strict.tls*cipher*policy*1*2*strict*with*1_3.自定义安全策略：输入自定义安全策略 ID。当Protocol为TLS 时，该参数为必填。。
        :param pulumi.Input[builtins.int] start_port: 全端口监听的起始端口，仅当Port为0时有效。
        """
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "server_group_id", server_group_id)
        if certificate_id is not None:
            pulumi.set(__self__, "certificate_id", certificate_id)
        if connection_timeout is not None:
            pulumi.set(__self__, "connection_timeout", connection_timeout)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if end_port is not None:
            pulumi.set(__self__, "end_port", end_port)
        if healths is not None:
            pulumi.set(__self__, "healths", healths)
        if listener_name is not None:
            pulumi.set(__self__, "listener_name", listener_name)
        if security_policy_id is not None:
            pulumi.set(__self__, "security_policy_id", security_policy_id)
        if start_port is not None:
            pulumi.set(__self__, "start_port", start_port)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Input[builtins.str]:
        """
        负载均衡实例ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter
    def port(self) -> pulumi.Input[builtins.int]:
        """
        监听器接收请求的端口，0表示启用全端口监听。
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[builtins.str]:
        """
        监听协议类型。TCP,UDP,TLS
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> pulumi.Input[builtins.str]:
        """
        监听器关联的服务器组ID。
        """
        return pulumi.get(self, "server_group_id")

    @server_group_id.setter
    def server_group_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "server_group_id", value)

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TLS监听器服务器证书的ID，仅支持传入证书中心 SSL 证书。。
        """
        return pulumi.get(self, "certificate_id")

    @certificate_id.setter
    def certificate_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "certificate_id", value)

    @property
    @pulumi.getter(name="connectionTimeout")
    def connection_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        监听器的连接超时时间（秒）。
        """
        return pulumi.get(self, "connection_timeout")

    @connection_timeout.setter
    def connection_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "connection_timeout", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否启用监听器。true：开启；false：关闭。
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="endPort")
    def end_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        全端口监听的结束端口，仅当Port为0时有效。
        """
        return pulumi.get(self, "end_port")

    @end_port.setter
    def end_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "end_port", value)

    @property
    @pulumi.getter
    def healths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbListenerHealthArgs']]]]:
        return pulumi.get(self, "healths")

    @healths.setter
    def healths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbListenerHealthArgs']]]]):
        pulumi.set(self, "healths", value)

    @property
    @pulumi.getter(name="listenerName")
    def listener_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器名称。
        """
        return pulumi.get(self, "listener_name")

    @listener_name.setter
    def listener_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "listener_name", value)

    @property
    @pulumi.getter(name="securityPolicyId")
    def security_policy_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TLS 安全策略ID，支持系统安全策略和自定义安全策略。系统安全策略取值：.tls*cipher*policy*1*0.tls*cipher*policy*1*1.tls*cipher*policy*1*2.tls*cipher*policy*1*2*strict.tls*cipher*policy*1*2*strict*with*1_3.自定义安全策略：输入自定义安全策略 ID。当Protocol为TLS 时，该参数为必填。。
        """
        return pulumi.get(self, "security_policy_id")

    @security_policy_id.setter
    def security_policy_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_policy_id", value)

    @property
    @pulumi.getter(name="startPort")
    def start_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        全端口监听的起始端口，仅当Port为0时有效。
        """
        return pulumi.get(self, "start_port")

    @start_port.setter
    def start_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "start_port", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbListenerTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbListenerTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _NlbListenerState:
    def __init__(__self__, *,
                 certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 connection_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 end_port: Optional[pulumi.Input[builtins.int]] = None,
                 healths: Optional[pulumi.Input[Sequence[pulumi.Input['NlbListenerHealthArgs']]]] = None,
                 listener_id: Optional[pulumi.Input[builtins.str]] = None,
                 listener_name: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 security_policy_id: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 start_port: Optional[pulumi.Input[builtins.int]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['NlbListenerTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering NlbListener resources.
        :param pulumi.Input[builtins.str] certificate_id: TLS监听器服务器证书的ID，仅支持传入证书中心 SSL 证书。。
        :param pulumi.Input[builtins.int] connection_timeout: 监听器的连接超时时间（秒）。
        :param pulumi.Input[builtins.str] created_time: 监听器的创建时间。
        :param pulumi.Input[builtins.str] description: 监听器描述信息。
        :param pulumi.Input[builtins.bool] enabled: 是否启用监听器。true：开启；false：关闭。
        :param pulumi.Input[builtins.int] end_port: 全端口监听的结束端口，仅当Port为0时有效。
        :param pulumi.Input[builtins.str] listener_id: 监听器唯一标识。
        :param pulumi.Input[builtins.str] listener_name: 监听器名称。
        :param pulumi.Input[builtins.str] load_balancer_id: 负载均衡实例ID。
        :param pulumi.Input[builtins.int] port: 监听器接收请求的端口，0表示启用全端口监听。
        :param pulumi.Input[builtins.str] protocol: 监听协议类型。TCP,UDP,TLS
        :param pulumi.Input[builtins.str] security_policy_id: TLS 安全策略ID，支持系统安全策略和自定义安全策略。系统安全策略取值：.tls*cipher*policy*1*0.tls*cipher*policy*1*1.tls*cipher*policy*1*2.tls*cipher*policy*1*2*strict.tls*cipher*policy*1*2*strict*with*1_3.自定义安全策略：输入自定义安全策略 ID。当Protocol为TLS 时，该参数为必填。。
        :param pulumi.Input[builtins.str] server_group_id: 监听器关联的服务器组ID。
        :param pulumi.Input[builtins.int] start_port: 全端口监听的起始端口，仅当Port为0时有效。
        :param pulumi.Input[builtins.str] status: 监听器的状态。
        :param pulumi.Input[builtins.str] updated_time: 监听器最近操作时间。
        """
        if certificate_id is not None:
            pulumi.set(__self__, "certificate_id", certificate_id)
        if connection_timeout is not None:
            pulumi.set(__self__, "connection_timeout", connection_timeout)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if end_port is not None:
            pulumi.set(__self__, "end_port", end_port)
        if healths is not None:
            pulumi.set(__self__, "healths", healths)
        if listener_id is not None:
            pulumi.set(__self__, "listener_id", listener_id)
        if listener_name is not None:
            pulumi.set(__self__, "listener_name", listener_name)
        if load_balancer_id is not None:
            pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if security_policy_id is not None:
            pulumi.set(__self__, "security_policy_id", security_policy_id)
        if server_group_id is not None:
            pulumi.set(__self__, "server_group_id", server_group_id)
        if start_port is not None:
            pulumi.set(__self__, "start_port", start_port)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TLS监听器服务器证书的ID，仅支持传入证书中心 SSL 证书。。
        """
        return pulumi.get(self, "certificate_id")

    @certificate_id.setter
    def certificate_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "certificate_id", value)

    @property
    @pulumi.getter(name="connectionTimeout")
    def connection_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        监听器的连接超时时间（秒）。
        """
        return pulumi.get(self, "connection_timeout")

    @connection_timeout.setter
    def connection_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "connection_timeout", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否启用监听器。true：开启；false：关闭。
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="endPort")
    def end_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        全端口监听的结束端口，仅当Port为0时有效。
        """
        return pulumi.get(self, "end_port")

    @end_port.setter
    def end_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "end_port", value)

    @property
    @pulumi.getter
    def healths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbListenerHealthArgs']]]]:
        return pulumi.get(self, "healths")

    @healths.setter
    def healths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbListenerHealthArgs']]]]):
        pulumi.set(self, "healths", value)

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器唯一标识。
        """
        return pulumi.get(self, "listener_id")

    @listener_id.setter
    def listener_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "listener_id", value)

    @property
    @pulumi.getter(name="listenerName")
    def listener_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器名称。
        """
        return pulumi.get(self, "listener_name")

    @listener_name.setter
    def listener_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "listener_name", value)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        负载均衡实例ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        监听器接收请求的端口，0表示启用全端口监听。
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听协议类型。TCP,UDP,TLS
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="securityPolicyId")
    def security_policy_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TLS 安全策略ID，支持系统安全策略和自定义安全策略。系统安全策略取值：.tls*cipher*policy*1*0.tls*cipher*policy*1*1.tls*cipher*policy*1*2.tls*cipher*policy*1*2*strict.tls*cipher*policy*1*2*strict*with*1_3.自定义安全策略：输入自定义安全策略 ID。当Protocol为TLS 时，该参数为必填。。
        """
        return pulumi.get(self, "security_policy_id")

    @security_policy_id.setter
    def security_policy_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "security_policy_id", value)

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器关联的服务器组ID。
        """
        return pulumi.get(self, "server_group_id")

    @server_group_id.setter
    def server_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_id", value)

    @property
    @pulumi.getter(name="startPort")
    def start_port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        全端口监听的起始端口，仅当Port为0时有效。
        """
        return pulumi.get(self, "start_port")

    @start_port.setter
    def start_port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "start_port", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器的状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NlbListenerTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NlbListenerTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        监听器最近操作时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:clb/nlbListener:NlbListener")
class NlbListener(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 connection_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 end_port: Optional[pulumi.Input[builtins.int]] = None,
                 healths: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbListenerHealthArgs', 'NlbListenerHealthArgsDict']]]]] = None,
                 listener_name: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 security_policy_id: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 start_port: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbListenerTagArgs', 'NlbListenerTagArgsDict']]]]] = None,
                 __props__=None):
        """
        监听器负责根据指定的协议和端口，监听NLB实例接收到的用户访问请求。NLB将按照该监听器关联的服务器组配置的调度算法，将访问请求转发至该服务器组内健康的后端服务器。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        c_lbnlb_listener_demo = bytepluscc.clb.NlbListener("CLBNLBListenerDemo",
            load_balancer_id="nlb-11zz9w3jqptz449iegfwvxxxx",
            protocol="TCP",
            port=0,
            server_group_id="rsp-11zz9wdewa3uo49ieggq8xxxx",
            connection_timeout=60,
            description="CLBNLBListenerDemo description",
            enabled=True,
            listener_name="CLBNLBListenerDemo",
            tags=[{
                "key": "env",
                "value": "Test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/nlbListener:NlbListener example "listener_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] certificate_id: TLS监听器服务器证书的ID，仅支持传入证书中心 SSL 证书。。
        :param pulumi.Input[builtins.int] connection_timeout: 监听器的连接超时时间（秒）。
        :param pulumi.Input[builtins.str] description: 监听器描述信息。
        :param pulumi.Input[builtins.bool] enabled: 是否启用监听器。true：开启；false：关闭。
        :param pulumi.Input[builtins.int] end_port: 全端口监听的结束端口，仅当Port为0时有效。
        :param pulumi.Input[builtins.str] listener_name: 监听器名称。
        :param pulumi.Input[builtins.str] load_balancer_id: 负载均衡实例ID。
        :param pulumi.Input[builtins.int] port: 监听器接收请求的端口，0表示启用全端口监听。
        :param pulumi.Input[builtins.str] protocol: 监听协议类型。TCP,UDP,TLS
        :param pulumi.Input[builtins.str] security_policy_id: TLS 安全策略ID，支持系统安全策略和自定义安全策略。系统安全策略取值：.tls*cipher*policy*1*0.tls*cipher*policy*1*1.tls*cipher*policy*1*2.tls*cipher*policy*1*2*strict.tls*cipher*policy*1*2*strict*with*1_3.自定义安全策略：输入自定义安全策略 ID。当Protocol为TLS 时，该参数为必填。。
        :param pulumi.Input[builtins.str] server_group_id: 监听器关联的服务器组ID。
        :param pulumi.Input[builtins.int] start_port: 全端口监听的起始端口，仅当Port为0时有效。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NlbListenerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        监听器负责根据指定的协议和端口，监听NLB实例接收到的用户访问请求。NLB将按照该监听器关联的服务器组配置的调度算法，将访问请求转发至该服务器组内健康的后端服务器。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        c_lbnlb_listener_demo = bytepluscc.clb.NlbListener("CLBNLBListenerDemo",
            load_balancer_id="nlb-11zz9w3jqptz449iegfwvxxxx",
            protocol="TCP",
            port=0,
            server_group_id="rsp-11zz9wdewa3uo49ieggq8xxxx",
            connection_timeout=60,
            description="CLBNLBListenerDemo description",
            enabled=True,
            listener_name="CLBNLBListenerDemo",
            tags=[{
                "key": "env",
                "value": "Test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:clb/nlbListener:NlbListener example "listener_id"
        ```

        :param str resource_name: The name of the resource.
        :param NlbListenerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NlbListenerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 certificate_id: Optional[pulumi.Input[builtins.str]] = None,
                 connection_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 end_port: Optional[pulumi.Input[builtins.int]] = None,
                 healths: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbListenerHealthArgs', 'NlbListenerHealthArgsDict']]]]] = None,
                 listener_name: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 security_policy_id: Optional[pulumi.Input[builtins.str]] = None,
                 server_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 start_port: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbListenerTagArgs', 'NlbListenerTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NlbListenerArgs.__new__(NlbListenerArgs)

            __props__.__dict__["certificate_id"] = certificate_id
            __props__.__dict__["connection_timeout"] = connection_timeout
            __props__.__dict__["description"] = description
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["end_port"] = end_port
            __props__.__dict__["healths"] = healths
            __props__.__dict__["listener_name"] = listener_name
            if load_balancer_id is None and not opts.urn:
                raise TypeError("Missing required property 'load_balancer_id'")
            __props__.__dict__["load_balancer_id"] = load_balancer_id
            if port is None and not opts.urn:
                raise TypeError("Missing required property 'port'")
            __props__.__dict__["port"] = port
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["security_policy_id"] = security_policy_id
            if server_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'server_group_id'")
            __props__.__dict__["server_group_id"] = server_group_id
            __props__.__dict__["start_port"] = start_port
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_time"] = None
            __props__.__dict__["listener_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(NlbListener, __self__).__init__(
            'bytepluscc:clb/nlbListener:NlbListener',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            certificate_id: Optional[pulumi.Input[builtins.str]] = None,
            connection_timeout: Optional[pulumi.Input[builtins.int]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            end_port: Optional[pulumi.Input[builtins.int]] = None,
            healths: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbListenerHealthArgs', 'NlbListenerHealthArgsDict']]]]] = None,
            listener_id: Optional[pulumi.Input[builtins.str]] = None,
            listener_name: Optional[pulumi.Input[builtins.str]] = None,
            load_balancer_id: Optional[pulumi.Input[builtins.str]] = None,
            port: Optional[pulumi.Input[builtins.int]] = None,
            protocol: Optional[pulumi.Input[builtins.str]] = None,
            security_policy_id: Optional[pulumi.Input[builtins.str]] = None,
            server_group_id: Optional[pulumi.Input[builtins.str]] = None,
            start_port: Optional[pulumi.Input[builtins.int]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NlbListenerTagArgs', 'NlbListenerTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'NlbListener':
        """
        Get an existing NlbListener resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] certificate_id: TLS监听器服务器证书的ID，仅支持传入证书中心 SSL 证书。。
        :param pulumi.Input[builtins.int] connection_timeout: 监听器的连接超时时间（秒）。
        :param pulumi.Input[builtins.str] created_time: 监听器的创建时间。
        :param pulumi.Input[builtins.str] description: 监听器描述信息。
        :param pulumi.Input[builtins.bool] enabled: 是否启用监听器。true：开启；false：关闭。
        :param pulumi.Input[builtins.int] end_port: 全端口监听的结束端口，仅当Port为0时有效。
        :param pulumi.Input[builtins.str] listener_id: 监听器唯一标识。
        :param pulumi.Input[builtins.str] listener_name: 监听器名称。
        :param pulumi.Input[builtins.str] load_balancer_id: 负载均衡实例ID。
        :param pulumi.Input[builtins.int] port: 监听器接收请求的端口，0表示启用全端口监听。
        :param pulumi.Input[builtins.str] protocol: 监听协议类型。TCP,UDP,TLS
        :param pulumi.Input[builtins.str] security_policy_id: TLS 安全策略ID，支持系统安全策略和自定义安全策略。系统安全策略取值：.tls*cipher*policy*1*0.tls*cipher*policy*1*1.tls*cipher*policy*1*2.tls*cipher*policy*1*2*strict.tls*cipher*policy*1*2*strict*with*1_3.自定义安全策略：输入自定义安全策略 ID。当Protocol为TLS 时，该参数为必填。。
        :param pulumi.Input[builtins.str] server_group_id: 监听器关联的服务器组ID。
        :param pulumi.Input[builtins.int] start_port: 全端口监听的起始端口，仅当Port为0时有效。
        :param pulumi.Input[builtins.str] status: 监听器的状态。
        :param pulumi.Input[builtins.str] updated_time: 监听器最近操作时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NlbListenerState.__new__(_NlbListenerState)

        __props__.__dict__["certificate_id"] = certificate_id
        __props__.__dict__["connection_timeout"] = connection_timeout
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["end_port"] = end_port
        __props__.__dict__["healths"] = healths
        __props__.__dict__["listener_id"] = listener_id
        __props__.__dict__["listener_name"] = listener_name
        __props__.__dict__["load_balancer_id"] = load_balancer_id
        __props__.__dict__["port"] = port
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["security_policy_id"] = security_policy_id
        __props__.__dict__["server_group_id"] = server_group_id
        __props__.__dict__["start_port"] = start_port
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        return NlbListener(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> pulumi.Output[builtins.str]:
        """
        TLS监听器服务器证书的ID，仅支持传入证书中心 SSL 证书。。
        """
        return pulumi.get(self, "certificate_id")

    @property
    @pulumi.getter(name="connectionTimeout")
    def connection_timeout(self) -> pulumi.Output[builtins.int]:
        """
        监听器的连接超时时间（秒）。
        """
        return pulumi.get(self, "connection_timeout")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        监听器的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        监听器描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否启用监听器。true：开启；false：关闭。
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="endPort")
    def end_port(self) -> pulumi.Output[builtins.int]:
        """
        全端口监听的结束端口，仅当Port为0时有效。
        """
        return pulumi.get(self, "end_port")

    @property
    @pulumi.getter
    def healths(self) -> pulumi.Output[Sequence['outputs.NlbListenerHealth']]:
        return pulumi.get(self, "healths")

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> pulumi.Output[builtins.str]:
        """
        监听器唯一标识。
        """
        return pulumi.get(self, "listener_id")

    @property
    @pulumi.getter(name="listenerName")
    def listener_name(self) -> pulumi.Output[builtins.str]:
        """
        监听器名称。
        """
        return pulumi.get(self, "listener_name")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Output[builtins.str]:
        """
        负载均衡实例ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[builtins.int]:
        """
        监听器接收请求的端口，0表示启用全端口监听。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[builtins.str]:
        """
        监听协议类型。TCP,UDP,TLS
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="securityPolicyId")
    def security_policy_id(self) -> pulumi.Output[builtins.str]:
        """
        TLS 安全策略ID，支持系统安全策略和自定义安全策略。系统安全策略取值：.tls*cipher*policy*1*0.tls*cipher*policy*1*1.tls*cipher*policy*1*2.tls*cipher*policy*1*2*strict.tls*cipher*policy*1*2*strict*with*1_3.自定义安全策略：输入自定义安全策略 ID。当Protocol为TLS 时，该参数为必填。。
        """
        return pulumi.get(self, "security_policy_id")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> pulumi.Output[builtins.str]:
        """
        监听器关联的服务器组ID。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter(name="startPort")
    def start_port(self) -> pulumi.Output[builtins.int]:
        """
        全端口监听的起始端口，仅当Port为0时有效。
        """
        return pulumi.get(self, "start_port")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        监听器的状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.NlbListenerTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        监听器最近操作时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetGroupResult',
    'AwaitableGetGroupResult',
    'get_group',
    'get_group_output',
]

@pulumi.output_type
class GetGroupResult:
    """
    A collection of values returned by getGroup.
    """
    def __init__(__self__, created_time=None, description=None, group_id=None, group_name=None, id=None, instance_id=None, owner_id=None, owner_name=None, reset_info=None, status=None, topic_infos=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if group_id and not isinstance(group_id, str):
            raise TypeError("Expected argument 'group_id' to be a str")
        pulumi.set(__self__, "group_id", group_id)
        if group_name and not isinstance(group_name, str):
            raise TypeError("Expected argument 'group_name' to be a str")
        pulumi.set(__self__, "group_name", group_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if owner_id and not isinstance(owner_id, str):
            raise TypeError("Expected argument 'owner_id' to be a str")
        pulumi.set(__self__, "owner_id", owner_id)
        if owner_name and not isinstance(owner_name, str):
            raise TypeError("Expected argument 'owner_name' to be a str")
        pulumi.set(__self__, "owner_name", owner_name)
        if reset_info and not isinstance(reset_info, dict):
            raise TypeError("Expected argument 'reset_info' to be a dict")
        pulumi.set(__self__, "reset_info", reset_info)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if topic_infos and not isinstance(topic_infos, list):
            raise TypeError("Expected argument 'topic_infos' to be a list")
        pulumi.set(__self__, "topic_infos", topic_infos)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        Consumer Group 创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Consumer Group 描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> builtins.str:
        """
        Consumer Group 的 ID。
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> builtins.str:
        """
        自定义设置Consumer Group 的名称，约束限制如下：只能由小写英文字符、数字、下划线和中划线（-）组成。长度为 3~64 字符。
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        所属 BMQ 实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="ownerId")
    def owner_id(self) -> builtins.str:
        """
        Consumer Group 所属用户的 ID。
        """
        return pulumi.get(self, "owner_id")

    @property
    @pulumi.getter(name="ownerName")
    def owner_name(self) -> builtins.str:
        """
        Consumer Group 所属用户的名称。
        """
        return pulumi.get(self, "owner_name")

    @property
    @pulumi.getter(name="resetInfo")
    def reset_info(self) -> 'outputs.GetGroupResetInfoResult':
        """
        重置消费位点信息。
        """
        return pulumi.get(self, "reset_info")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Consumer Group 的状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="topicInfos")
    def topic_infos(self) -> Sequence['outputs.GetGroupTopicInfoResult']:
        """
        Topic 列表。
        """
        return pulumi.get(self, "topic_infos")


class AwaitableGetGroupResult(GetGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupResult(
            created_time=self.created_time,
            description=self.description,
            group_id=self.group_id,
            group_name=self.group_name,
            id=self.id,
            instance_id=self.instance_id,
            owner_id=self.owner_id,
            owner_name=self.owner_name,
            reset_info=self.reset_info,
            status=self.status,
            topic_infos=self.topic_infos)


def get_group(id: Optional[builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupResult:
    """
    Data Source schema for Byteplus::BMQ::Group


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:bmq/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult).value

    return AwaitableGetGroupResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        group_id=pulumi.get(__ret__, 'group_id'),
        group_name=pulumi.get(__ret__, 'group_name'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        owner_id=pulumi.get(__ret__, 'owner_id'),
        owner_name=pulumi.get(__ret__, 'owner_name'),
        reset_info=pulumi.get(__ret__, 'reset_info'),
        status=pulumi.get(__ret__, 'status'),
        topic_infos=pulumi.get(__ret__, 'topic_infos'))
def get_group_output(id: Optional[pulumi.Input[builtins.str]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupResult]:
    """
    Data Source schema for Byteplus::BMQ::Group


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:bmq/getGroup:getGroup', __args__, opts=opts, typ=GetGroupResult)
    return __ret__.apply(lambda __response__: GetGroupResult(
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        group_id=pulumi.get(__response__, 'group_id'),
        group_name=pulumi.get(__response__, 'group_name'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        owner_id=pulumi.get(__response__, 'owner_id'),
        owner_name=pulumi.get(__response__, 'owner_name'),
        reset_info=pulumi.get(__response__, 'reset_info'),
        status=pulumi.get(__response__, 'status'),
        topic_infos=pulumi.get(__response__, 'topic_infos')))
